import * as React from 'react';
import {
  Table, Header, Container, Form, Checkbox, Button, Rating,
  List, Icon, Grid, Modal,
} from 'semantic-ui-react';
import { SensorConfig } from './sensor_config';
import { SensorConfigSetting } from './sensor_config_setting';

export interface StateProps {
  open?: boolean;
  closeCallback?(): void;
}

export interface DispatchProps {
}

export type Props = StateProps & DispatchProps;

export interface State {
  startPopup: boolean;
  step: number;
}

export class SensorConfigPopup extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);

    this.state = {
      startPopup: false,
      step: 1,
    };
  }

  public handlePopupClose = () => {
    this.props.closeCallback();
  }

  // public handleCancel = () => this.setState({ startPopup: false });

  public handleSubmit(): void {
    this.setState({ startPopup: false, step: 1 });
    this.props.closeCallback();
  }

  public handleNext(): void {
    this.setState({ step: 2 });
  }

  public render(): JSX.Element {
    return (
      <Modal
        open={this.props.open}
      >
        <Modal.Content>
          <Container fluid>
            <Header as='h3' dividing>Sensor Config</Header>
            <br />

            <Modal size='small' open={this.props.open} onClose={this.handlePopupClose.bind(this)}>
              <Modal.Header>Discovery</Modal.Header>
              <Modal.Content >
                {this.state.step === 1 ?
                  <SensorConfig />
                  :
                  <SensorConfigSetting />
                }

              </Modal.Content>
              <Modal.Actions>
                <Button floated='left' onClick={this.handlePopupClose}>Cancel</Button>
                {this.state.step === 1 ?
                  <Button floated='right' onClick={this.handleNext.bind(this)} primary>Next</Button>
                  :
                  <Button floated='right' onClick={this.handleSubmit.bind(this)} primary>Done</Button>
                }
              </Modal.Actions>
            </Modal>

          </Container>
        </Modal.Content>
        <Modal.Actions>
        </Modal.Actions>
      </Modal>
    );
  }

}
